```
Usage: vcd network routed edit [OPTIONS] <name>

Options:
  -n, --name <name>               new name of org vdc network  [required]
  --description <description>     new description
  --shared-enabled / --shared-disabled
                                  share this network with other VDCs in the
                                  organization
  -h, --help                      Show this message and exit.

```
